#ifndef _ArtFile_H_
#define _ArtFile_H_

#include "stdafx.h"
#include "fileformatdefs.h"
#include "vardefs.h"
#include <stdio.h>
#include "basefile.h"

/*! This class is used to deal with \b ART files */
class ArtFile : public BaseFile
{
public:

	/*! Read an \b ART file straight from the GroupFile */
	ArtFile(FILESTRUCT* data);

	/*! Load an \b ART file from disk */
	ArtFile(const char* sFilename);

	/*! Create an empty \b ART file */
	ArtFile();

	~ArtFile();

	/*! Returns the current \b ART file version  */
	uint32 GetVersion(){ return m_Art.nVersion; }

	/*!
		Returns the number of tiles in the ART archive. \b Note: don't use this number.
		If you want to get the correct number, use (nTileEnd - nTileStart)
	*/
	uint32 GetNumTiles(){ return m_Art.nNumTiles; }

	/*! Returns the number of the \em first tile in the \b ART file */
	uint32 GetTileStart(){ return m_Art.nTileStart; }

	/*! Returns the number of the \em last tile in the \b ART file */
	uint32 GetTileEnd(){ return m_Art.nTileEnd; }

	/*! Returns the X dimension of the tile in index \em nNum */
	uint16 GetTileSizeX(uint32 nNum);
	
	/*! Returns the Y dimension of the tile in index \em nNum */
	uint16 GetTileSizeY(uint32 nNum);

	/*! Returns a pointer to the actual \em ARTSTRUCT data */
	ARTSTRUCT* GetDataHandle(){ return &m_Art; }

protected:

	/*! Art data */
	ARTSTRUCT m_Art;
};

#endif

