#include "stdafx.h"
#include "mapfile.h"
#include <string.h>

MapFile::MapFile(FILESTRUCT* data)
{
	if(data == NULL)
	{
		m_nStatus = BL_ERROR;
		return;
	}

	m_nStatus = BL_OK;

	//Get fileheader info
	strncpy(m_FileHeader.name, data->fileheader.name, 12);
	m_FileHeader.size = data->fileheader.size;

	uint32 nMemOffset = 0; 
	memcpy(&m_Map.nVersion, &data->data[nMemOffset], 4);
	nMemOffset += (sizeof(char) * 4);

	memcpy(&m_Map.StartPosition.x, &data->data[nMemOffset], 4);
	nMemOffset += (sizeof(char) * 4);
	
	memcpy(&m_Map.StartPosition.y, &data->data[nMemOffset], 4);
	nMemOffset += (sizeof(char) * 4);
	
	memcpy(&m_Map.StartPosition.z, &data->data[nMemOffset], 4);
	nMemOffset += (sizeof(char) * 4);	
	
	memcpy(&m_Map.nAngle , &data->data[nMemOffset], 2);
	nMemOffset += (sizeof(char) * 2);

	memcpy(&m_Map.nStartPointSecNum , &data->data[nMemOffset], 2);
	nMemOffset += (sizeof(char) * 2);

	//Read sector info
	memcpy(&m_Map.nNumSectors , &data->data[nMemOffset], 2);
	nMemOffset += (sizeof(char) * 2);

	memcpy(&m_Map.sectors[0] , &data->data[nMemOffset], m_Map.nNumSectors);
	nMemOffset += (sizeof(sectortype) * m_Map.nNumSectors);

	//Read wall info
	memcpy(&m_Map.nNumWalls , &data->data[nMemOffset], 2);
	nMemOffset += (sizeof(char) * 2);
	
	memcpy(&m_Map.walls[0] , &data->data[nMemOffset], m_Map.nNumWalls);
	nMemOffset += (sizeof(walltype) * m_Map.nNumWalls);

	//Read sprite info
	memcpy(&m_Map.nNumSprites , &data->data[nMemOffset], 2);
	nMemOffset += (sizeof(char) * 2);
	
	memcpy(&m_Map.sprites[0] , &data->data[nMemOffset], m_Map.nNumSprites);
	nMemOffset += (sizeof(spritetype) * m_Map.nNumSprites);

}


MapFile::MapFile(const char* sFilename)
{
	m_nStatus = BL_OK;

	FILE *fp = fopen(sFilename, "rb");
	if(fp != NULL)
	{
		//Read map version
		fread(&m_Map.nVersion, sizeof(char), 4, fp);

		fread(&m_Map.StartPosition.x, sizeof(char), 4, fp);
		fread(&m_Map.StartPosition.y, sizeof(char), 4, fp);
		fread(&m_Map.StartPosition.z, sizeof(char), 4, fp);


		fread(&m_Map.nAngle, sizeof(char), 2, fp);
		fread(&m_Map.nStartPointSecNum, sizeof(char), 2, fp);

		//Read sector info
		fread(&m_Map.nNumSectors, sizeof(char), 2, fp);
		fread(&m_Map.sectors[0], sizeof(sectortype), m_Map.nNumSectors, fp);

		//Read wall info
		fread(&m_Map.nNumWalls, sizeof(char), 2, fp);
		fread(&m_Map.walls[0], sizeof(walltype), m_Map.nNumWalls, fp);

		//Read sprite info
		fread(&m_Map.nNumSprites, sizeof(char), 2, fp);
		fread(&m_Map.sprites[0], sizeof(spritetype), m_Map.nNumSprites, fp);

		fclose(fp);
	}
	else
	{
		m_nStatus = BL_ERROR;
	}


}

MapFile::MapFile()
{
	m_nStatus = BL_OK;
}


MapFile::~MapFile()
{
}
